==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERSURVEYTRIGGERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUSTOMERSURVEYTRIGGERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERSURVEYTRIGGERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERSURVEYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMAILSOURCE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERSURVEYTRIGGERID_Type", propOrder = {
    "customersurveyid",
    "entity",
    "status",
    "emailsource"
})
public class CUSTOMERSURVEYTRIGGERID_Type {

    @XmlElement(name = "CUSTOMERSURVEYID", required = true)
    protected CUSTOMERSURVEYID_Type customersurveyid;
    @XmlElement(name = "ENTITY", required = true)
    protected String entity;
    @XmlElement(name = "STATUS", required = true)
    protected STATUS_Type status;
    @XmlElement(name = "EMAILSOURCE", required = true)
    protected String emailsource;

    /**
     * Gets the value of the customersurveyid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERSURVEYID_Type }
     *     
     */
    public CUSTOMERSURVEYID_Type getCUSTOMERSURVEYID() {
        return customersurveyid;
    }

    /**
     * Sets the value of the customersurveyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERSURVEYID_Type }
     *     
     */
    public void setCUSTOMERSURVEYID(CUSTOMERSURVEYID_Type value) {
        this.customersurveyid = value;
    }

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Gets the value of the status property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Gets the value of the emailsource property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMAILSOURCE() {
        return emailsource;
    }

    /**
     * Sets the value of the emailsource property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMAILSOURCE(String value) {
        this.emailsource = value;
    }

}

==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/CUSTOMERSURVEYTRIGGERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CUSTOMERSURVEYTRIGGERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMERSURVEYTRIGGERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERSURVEYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMAILSOURCE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMERSURVEYTRIGGERID_Type", propOrder = {
    "customersurveyid",
    "entity",
    "status",
    "emailsource"
})
public class CUSTOMERSURVEYTRIGGERID_Type {

    @XmlElement(name = "CUSTOMERSURVEYID", required = true)
    protected CUSTOMERSURVEYID_Type customersurveyid;
    @XmlElement(name = "ENTITY", required = true)
    protected String entity;
    @XmlElement(name = "STATUS", required = true)
    protected STATUS_Type status;
    @XmlElement(name = "EMAILSOURCE", required = true)
    protected String emailsource;

    /**
     * Obtient la valeur de la propriété customersurveyid.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERSURVEYID_Type }
     *     
     */
    public CUSTOMERSURVEYID_Type getCUSTOMERSURVEYID() {
        return customersurveyid;
    }

    /**
     * Définit la valeur de la propriété customersurveyid.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERSURVEYID_Type }
     *     
     */
    public void setCUSTOMERSURVEYID(CUSTOMERSURVEYID_Type value) {
        this.customersurveyid = value;
    }

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTITY() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTITY(String value) {
        this.entity = value;
    }

    /**
     * Obtient la valeur de la propriété status.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Définit la valeur de la propriété status.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Obtient la valeur de la propriété emailsource.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEMAILSOURCE() {
        return emailsource;
    }

    /**
     * Définit la valeur de la propriété emailsource.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEMAILSOURCE(String value) {
        this.emailsource = value;
    }

}
